
# RPC



[![PyPI version](https://badge.fury.io/py/twentyc.rpc.svg)](https://badge.fury.io/py/twentyc.rpc)
[![Build Status](https://travis-ci.org/20c/twentyc.rpc.svg?branch=master)](https://travis-ci.org/20c/twentyc.rpc)
[![Code Health](https://landscape.io/github/20c/twentyc.rpc/master/landscape.svg?style=flat)](https://landscape.io/github/20c/twentyc.rpc/master)
[![Codecov](https://img.shields.io/codecov/c/github/20c/twentyc.rpc/master.svg?maxAge=2592000)](https://codecov.io/github/20c/twentyc.rpc)
[![Requires.io](https://img.shields.io/requires/github/20c/twentyc.rpc.svg?maxAge=2592000)](https://requires.io/github/20c/twentyc.rpc/requirements)



client for 20c's RESTful API

